# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/) 
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.1] - 2016-09-10
### Fixed
- Missing `MANIFEST.in` caused pip builds to fail..
- Added `__unicode__` for Python 2.

### Added
- Test coverage.


## [0.1.0] - 2016-09-09
### Added
- Implementation and tests for a deterministic PDA routine helpers.
- Color tables generator.
- Alpha release.

### Changed
- Readme updated.


## 0.0.1 - 2016-09-09
### Added
- Initial project, this CHANGELOG.
- Test skeleton.
- Project skeleton.


[Unreleased]: https://github.com/prashnts/hues/compare/0.1.0...HEAD
[0.1.1]: https://github.com/prashnts/hues/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/prashnts/hues/compare/0.0.1...0.1.0

